Changelog
=========

1.0.0 (2019-06-06)
------------------

- Upgrade to Kinto 13 and Python 3.7


0.6.0 (2017-04-25)
------------------

- Upgrade to Kinto 6 and Python 3.5 (#21)


0.5.0 (2017-02-21)
------------------

- Fixing some common 500 with the plugin (#20)

0.4.0 (2016-12-02)
------------------

- Add the plugin version in the capability. (#12)
- Handle the ``pusher.cluster`` option. (#17)
- Update to super Kinto 5.0


0.3.0 (2016-05-23)
------------------

- Project renamed to *Kinto-fxa* to match the rename of ``cliquet`` to
  ``kinto.core``.

- Update to ``kinto.core`` for compatibility with Kinto 3.0. This
  release is no longer compatible with Kinto < 3.0, please upgrade!


0.2.0 (2015-11-20)
------------------

- Add HTML demo with *Kinto* and *Leaflet*
- Works with *Cliquet* 2.11


0.1.0 (2015-11-05)
------------------

- Initial working proof-of-concept.
